==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkGenericDataObjectReader.java <==
// java wrapper for vtkGenericDataObjectReader object
//

package vtk;
import vtk.*;

public class vtkGenericDataObjectReader extends vtkDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkDataObject GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkDataObject GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGraphOutput_4();
  public vtkGraph GetGraphOutput() {
    long temp = GetGraphOutput_4();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetMoleculeOutput_5();
  public vtkMolecule GetMoleculeOutput() {
    long temp = GetMoleculeOutput_5();

    if (temp == 0) return null;
    return (vtkMolecule)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_6();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_6();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_7();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_8();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_8();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_9();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_9();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTableOutput_10();
  public vtkTable GetTableOutput() {
    long temp = GetTableOutput_10();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTreeOutput_11();
  public vtkTree GetTreeOutput() {
    long temp = GetTreeOutput_11();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_12();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_12();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int ReadOutputType_13();
  public int ReadOutputType()
    { return ReadOutputType_13(); }

  public vtkGenericDataObjectReader() { super(); }

  public vtkGenericDataObjectReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv6h.pkg.tar.xz: vtk/vtkGenericDataObjectReader.java <==
// java wrapper for vtkGenericDataObjectReader object
//

package vtk;
import vtk.*;

public class vtkGenericDataObjectReader extends vtkDataReader
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkDataObject GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkDataObject GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGraphOutput_4();
  public vtkGraph GetGraphOutput() {
    long temp = GetGraphOutput_4();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetMoleculeOutput_5();
  public vtkMolecule GetMoleculeOutput() {
    long temp = GetMoleculeOutput_5();

    if (temp == 0) return null;
    return (vtkMolecule)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_6();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_6();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridOutput_7();
  public vtkRectilinearGrid GetRectilinearGridOutput() {
    long temp = GetRectilinearGridOutput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_8();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_8();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsOutput_9();
  public vtkStructuredPoints GetStructuredPointsOutput() {
    long temp = GetStructuredPointsOutput_9();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTableOutput_10();
  public vtkTable GetTableOutput() {
    long temp = GetTableOutput_10();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTreeOutput_11();
  public vtkTree GetTreeOutput() {
    long temp = GetTreeOutput_11();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_12();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_12();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int ReadOutputType_13();
  public int ReadOutputType()
    { return ReadOutputType_13(); }

  private native int ReadMetaDataSimple_14(String id0,vtkInformation id1);
  public int ReadMetaDataSimple(String id0,vtkInformation id1)
    { return ReadMetaDataSimple_14(id0,id1); }

  private native int ReadMeshSimple_15(String id0,vtkDataObject id1);
  public int ReadMeshSimple(String id0,vtkDataObject id1)
    { return ReadMeshSimple_15(id0,id1); }

  public vtkGenericDataObjectReader() { super(); }

  public vtkGenericDataObjectReader(long id) { super(id); }
  public native long   VTKInit();

}
